@@ -30,6 +30,7 @@ describe 'tripleo::profile::base::keystone' do
       :oslomsg_notify_username => 'keystone2',
       :oslomsg_notify_password => 'baa',
       :oslomsg_notify_port     => '5678',
+      :memcached_ips           => [ '192.168.0.3', '192.168.0.4', '192.168.0.5' ],
     }
   end
 
@@ -62,7 +63,8 @@ describe 'tripleo::profile::base::keystone' do
       it 'should trigger complete configuration' do
         is_expected.to contain_class('keystone').with(
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
-          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0'
+          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
+          :cache_memcache_servers => [ '192.168.0.3:11211', '192.168.0.4:11211', '192.168.0.5:11211' ],
         )
         is_expected.to contain_class('keystone::config')
         is_expected.to contain_class('keystone::logging')
@@ -108,7 +110,8 @@ describe 'tripleo::profile::base::keystone' do
       it 'should trigger keystone configuration' do
         is_expected.to contain_class('keystone').with(
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
-          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0'
+          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
+          :cache_memcache_servers => [ '192.168.0.3:11211', '192.168.0.4:11211', '192.168.0.5:11211' ],
         )
         is_expected.to contain_class('keystone::config')
         is_expected.to contain_class('keystone::logging')
@@ -134,7 +137,8 @@ describe 'tripleo::profile::base::keystone' do
       it 'should trigger keystone configuration' do
         is_expected.to contain_class('keystone').with(
           :default_transport_url => 'rabbit://keystone1:foo@192.168.0.1:1234/?ssl=0',
-          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0'
+          :notification_transport_url => 'rabbit://keystone2:baa@192.168.0.2:5678/?ssl=0',
+          :cache_memcache_servers => [ '192.168.0.3:11211', '192.168.0.4:11211', '192.168.0.5:11211' ],
         )
         is_expected.to contain_class('keystone::config')
         is_expected.to contain_class('keystone::logging')
